##
##  git-appraise.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_git_appraise_base  0.7
%define       V_git_appraise_snap  20230811

#   package information
Name:         git-appraise
Summary:      Git Code Review Extension
URL:          https://github.com/google/git-appraise
Vendor:       Google Inc.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        SCM
License:      MIT
Version:      %{V_git_appraise_base}.%{V_git_appraise_snap}
Release:      20230811

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/git-appraise/git-appraise-%{V_git_appraise_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, rsync

%description
    Git-Appraise is a distributed code review system for Git repos.
    By "distributed", we mean that code reviews are stored inside
    of the repository as git objects. Every developer on your team
    has their own copy of the review history that they can push or
    pull. When pulling, updates from the remote repo are automatically
    merged by the tool. This design removes the need for any sort of
    server-side setup. As a result, this tool can work with any git
    hosting provider, and the only setup required is installing the
    client on your workstation.

%track
    prog git-appraise = {
        version   = %{V_git_appraise_base}
        url       = https://github.com/google/git-appraise/releases
        regex     = tree/v(\d+\.\d+(?:\.\d+)?)
    }

%prep
    %setup -q -n git-appraise

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/google/git-appraise
        go build -v -o git-appraise.exe git-appraise/*.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/git

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/google/git-appraise/git-appraise.exe \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/git/git-appraise

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

